==> drools-quarkus-unit-example-0.5.0-sources.jar: org/kie/kogito/rules/alerting/Rules4723952D402A230BDB0E7081EBBA10E2_LoggerServiceRuleMethods0.java <==
package org.kie.kogito.rules.alerting;

import java.util.*;
import org.drools.model.*;
import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import java.time.*;
import java.time.format.*;
import java.text.*;
import org.drools.core.util.*;
import static org.kie.kogito.rules.alerting.Rules4723952D402A230BDB0E7081EBBA10E2.*;

public class Rules4723952D402A230BDB0E7081EBBA10E2_LoggerServiceRuleMethods0 {

    /**
     * Rule name: org.kie.kogito.rules.alerting.LoggerService.IncomingAlert
     */
    public static org.drools.model.Rule rule_org_46kie_46kogito_46rules_46alerting_46LoggerService_46IncomingAlert() {
        final org.drools.model.Variable<org.kie.kogito.rules.alerting.Alert> var_$e = D.declarationOf(org.kie.kogito.rules.alerting.Alert.class,
                                                                                                      DomainClassesMetadata4723952D402A230BDB0E7081EBBA10E2.org_kie_kogito_rules_alerting_Alert_Metadata_INSTANCE,
                                                                                                      "$e",
                                                                                                      D.entryPoint("alertStream"));
        org.drools.model.Rule rule = D.rule("org.kie.kogito.rules.alerting",
                                            "org.kie.kogito.rules.alerting.LoggerService.IncomingAlert").unit(org.kie.kogito.rules.alerting.LoggerService.class)
                                                                                                        .build(D.pattern(var_$e),
                                                                                                               D.on(var_$e,
                                                                                                                    var_logger).execute(($e, logger) -> {
                                                                                                                   logger.append($e.getMessage());
                                                                                                               }));
        return rule;
    }
}

==> drools-quarkus-unit-example-0.7.1-sources.jar: org/kie/kogito/rules/alerting/Rules4723952D402A230BDB0E7081EBBA10E2_LoggerServiceRuleMethods0.java <==
package org.kie.kogito.rules.alerting;

import java.util.*;
import org.drools.model.*;
import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import java.time.*;
import java.time.format.*;
import java.text.*;
import org.drools.core.util.*;
import static org.kie.kogito.rules.alerting.Rules4723952D402A230BDB0E7081EBBA10E2.*;

public class Rules4723952D402A230BDB0E7081EBBA10E2_LoggerServiceRuleMethods0 {

    /**
     * Rule name: org.kie.kogito.rules.alerting.LoggerService.IncomingAlert
     */
    public static org.drools.model.Rule rule_org_46kie_46kogito_46rules_46alerting_46LoggerService_46IncomingAlert() {
        final org.drools.model.Variable<org.kie.kogito.rules.alerting.Alert> var_$e = D.declarationOf(org.kie.kogito.rules.alerting.Alert.class,
                                                                                                      DomainClassesMetadata4723952D402A230BDB0E7081EBBA10E2.org_kie_kogito_rules_alerting_Alert_Metadata_INSTANCE,
                                                                                                      "$e",
                                                                                                      D.entryPoint("alertStream"));
        org.drools.model.Rule rule = D.rule("org.kie.kogito.rules.alerting",
                                            "org.kie.kogito.rules.alerting.LoggerService.IncomingAlert").unit(org.kie.kogito.rules.alerting.LoggerService.class)
                                                                                                        .build(D.pattern(var_$e),
                                                                                                               D.on(var_$e,
                                                                                                                    var_logger).execute((org.kie.kogito.rules.alerting.Alert $e, org.kie.kogito.rules.DataStream logger) -> {
                                                                                                                   logger.append($e.getMessage());
                                                                                                               }));
        return rule;
    }
}
